cap program drop StableQuantiles
program define StableQuantiles, rclass

    syntax varlist(max=1 numeric) [if] [fweight aweight iweight] [, IDvars(varlist) GENvar(name) BY(varlist) BINS(integer 100) SORT(varlist) SEED(integer 1) display] 

    // This function calculates quantiles in the data, it is meant to be stable
    // across different computers. Other programs such as quantiles are
    // not alwas stable as they run into issues when there are ties at the 
    // cutoffs. 

    // HELP:
    * varlist: variable to be used to calculate the quantiles. REQUIRED
    * idvars:  variable(s) that uniquely identify observations in the the data.
    *          REQUIRED.
    * sort:    These variables will be used to sort the data if they want to 
    *          be used to break ties in varlist.
    *          reproducibility across computers. 
    * genvar:  name of the variable that will be created to store the 
    *          quantiles. REQUIRED
    * by:      variable(s) to calculate quantiles within groups.
    * bins:    number of quantiles to calculate. Default = 100
    * seed:    seed for the random number generator. Default = 1. This will
    *          guarantee reproducibility across computers.
    * display: if specified, will display the distribution of the created
    *          quantiles variable and the min and max values for each quantile. *          The tabulation only make sense if there are no BY() variables. 
    *          Display will only occur if bins<=100.

    // Some info MUST be provided
    if "`idvars'"==""{
        di as err "ERROR: IDvars() variables must be provided."
        exit 198
    }
    if "`genvar'"==""{
        di as err "ERROR: GENvar() variable must be provided."
        exit 198
    }

    confirm new variable `genvar'

    // ID variables must be unique 
    qui unique `idvars'
    if r(unique)!=r(N) {
        di as err "ERROR: IDvars() variables must be unique identifiers."
        exit 111
        ** Could have allowed to include the BY() variables for the unique 
        ** identifiers, but I avoid this issue by requiring the user to
        ** provide unique identifiers in the SORT()
    }
    if `bins' < 2 {
        di as error "ERROR: invalid BINS(); number of quantiles should be at least 2"
        exit 113
    }
    
    
    tempvar totweight weighting markervar ordervar cumulativevar noisevarlist currentorder
    mark `markervar' `if'
    markout `markervar' `varlist'

    if "`weight'"!=""{
        gen `weighting' `exp'
    }
    else{
        gen `weighting'=1
    }

    gen `currentorder'=_n
    sort `by' `idvars'
    set seed `seed' // To guarantee reproducibility across datasets
    gen `ordervar'=rnormal(0,1) // This variable will break ties if there are any.
    sort `currentorder' // Restore order
    //format `varlist' %14.6fc

    // Now order based on the random variable to break ties 
    sort `by' `varlist' `sort'  `ordervar'

    // Calculate the total weight and the cumulative weight
    if "`by'"!=""{
        egen `totweight'=total(`weighting') if `markervar', by(`by')
        bysort `by': gen `cumulativevar'=sum(`weighting') if `markervar'
    }
    else{
        egen `totweight'=total(`weighting') if `markervar'
        gen `cumulativevar'=sum(`weighting') if `markervar'
    }
    // Now calculate the quantiles
    // gen `genvar' =  .
    matrix display_pctiles = J(`bins',2,.)
    sum `cumulativevar' `totweight' if `markervar'
    
    // Potentially faster way 
    gen `genvar' = int(`cumulativevar'/((`totweight'+1)/`bins')) + 1 if `markervar'

    if "`by'"!="" label variable `genvar' "`bins' quantiles of `varlist' by `by'."
    else label variable `genvar' "`bins' quantiles of `varlist'."

    // Display some basic results: distribution across quantiles and cutoffs 
    // for each quantile
    if "`display'"!="" & `bins' <= 100{
        local rownamelist ""
        forvalues x = 1/`bins'{
            replace `genvar' = `x' if `markervar' & (`x'-1)*`totweight'/`bins'< `cumulativevar' & `cumulativevar' <= `x'*`totweight'/`bins'
            * Local of highest value within the quantile
            qui sum `varlist' if `markervar' & `genvar'==`x' 
            matrix display_pctiles[`x',2] = r(max)
            matrix display_pctiles[`x',1] = r(min)
            local rownamelist `rownamelist' `x'
        }
        *dis "`rownamelist'"
        matrix colnames display_pctiles = "Min" "Max" 
        matrix rownames display_pctiles = `rownamelist'
        
    
        if "`by'"!="" | "`weight'"!="" dis "Distribution across quantiles does not need to be balanced if there are weights. And distribution will only be balanced within groups defined by the BY() variables."
        tab `genvar' if `markervar'

    // Display the cutoffs for each quantile (if under 20, otherwise too many)
        matlist display_pctiles, border(rows) rowtitle("`genvar'") left(4) format(%9.3fc) title("Cutoffs for each quantile")
        
    }

    sort `currentorder' // Restore order

end