********************************************************************************
**
**							1. Nepal
**
********************************************************************************
**
**		This dofile processes the Nepal Labour Force Survey to produce
**		the results that are used in 2. Aggregate South Asia.do for
**		Figures 1, 2, and A2.
**		Author: Nicolas Urdaneta 
**
********************************************************************************

cap log close
log using "${results}/Logs/Log 1 Nepal `c(current_date)'.txt", replace text

use "${rawdata}/Nepal/S00_rc.dta", clear
merge 1:m hhld psu  using "${rawdata}/Nepal/S02_rc.dta" 	, nogen
merge 1:1 personid psu  using "${rawdata}/Nepal/S03_rc.dta"	, nogen
merge 1:1 personid psu  using "${rawdata}/Nepal/S04_rc.dta"	, nogen
merge 1:1 personid psu  using "${rawdata}/Nepal/S05_rc.dta"	, nogen
merge 1:1 personid psu  using "${rawdata}/Nepal/S06_rc.dta"	, nogen
merge 1:1 personid psu  using "${rawdata}/Nepal/weights.dta" , nogen

// check aggregates for urban/rural 
tab urbrur753 [iw=wt_prov_ind_year ] 

********************************************************************************
**
**		Create variables for analysis
**
********************************************************************************

// Characteristics
gen agegroups = (age<15)*1 + (inrange(age,15,25))*2 + (inrange(age,26,45))*3 + (inrange(age,46,65))*4 + (inrange(age,65,1000))*5
gen educgroups = (grade_comp<=10 | grade_comp>=16)*1+(inrange(grade_comp,11,12))*2+(inrange(grade_comp,13,15))*3
gen hrsworkgroups = 1*(inrange(allwrk_usulhr,1,19))+2*(inrange(allwrk_usulhr,20,39))+3*(inrange(allwrk_usulhr,40,1000))



// status: tab mwrk_status 
// firmsize: mwrk_empnum

gen selfemployed = (mwrk_status==4)
gen size = 1 if selfemployed==1 
replace size = 2 if selfemployed!=1 & mwrk_empnum<=2
replace size = 3 if selfemployed!=1 & mwrk_empnum==3
replace size = 4 if selfemployed!=1 & mwrk_empnum==4
replace size = 5 if selfemployed!=1 & mwrk_empnum==5

cap label drop sizes
label define sizes 1 "Self-employed" 2 "1-4 workers" 3 "5-9 workers" 4 "10-19 workers" 5 "20+ workers"
label values size sizes

gen rural= (urbrur753==2)
gen works = (wrk_paid==1 | wrk_busns==1)

// Create sector variables

gen gov_wkr = (mwrk_orgtype<=2 | inrange(mwrk_nsic4,8400,8499))
gen educ_sector = (inrange(mwrk_nsic4,8500,8599))

gen sector_categ = 1*(inrange(mwrk_nsic4,0500,3999))+2*(inrange(mwrk_nsic4,4500,4899) | inrange(mwrk_nsic4,55000,56999))+3*(inrange(mwrk_nsic4,5800,8299) | inrange(mwrk_nsic4,9000,9999)) + 4*(inrange(mwrk_nsic4,0,0499))
cap label drop categs
label define categs 1 "Industry" 2 "Services" 3 "Other services" 4 "Agriculture" 0 "Other sectors"
label values sector_categ categs
gen agro=(sector_categ==4)

// Create income variable

egen income0 = rowtotal(amt_cashrs faci_mktval)
replace income0 = amt_cashrs*30.4167 if prd_remu==1
replace income0 = amt_cashrs*4.34524 if prd_remu==2


*	____________________________________________________________________________
*
*			Impute income of those that report negative, zero or no income
*					but say they have a work with income
*	____________________________________________________________________________
 
gen income_censor = income0
replace income_censor = . if income0 <= 0

quantiles income_censor [iw=wt_prov_ind_year], gencatvar(pctiles) n(100) stable
replace income_censor = . if inlist(pctiles,1,100)

global covs sex educgroups agegroups mwrk_status hrsworkgroups agro

foreach var of global covs{
	replace income_censor = . if `var' == .
}

* ybar con factor de expansion
bys $covs: egen ing_mean_wt=wtmean(income_censor) if wrk_paid==1 & income_censor>0 & income_censor!=., weight(wt_prov_ind_year)
bys $covs: egen ing_i_mean_wt=min(ing_mean_wt) if wrk_paid==1 

gen income_imp = income0
replace income_imp = ing_i_mean_wt if wrk_paid == 1 & (income0==. | income0 <= 0) 
// We impute 557 observations, 52 kept as missing.
drop income_censor pctiles


// Create variables that will add to shares when collapsed
// Both in total and by sector

sum wt_prov_ind_year if age>=20 & (inrange(income_imp,0,100000000) | wrk_busns==1) & gov_wkr!=1 & educ_sector!=1 & works==1 & size!=. & rural==0, d
gen empsize = wt_prov_ind_year / r(sum)*100

gen emp_bysector_size=.
foreach sector in  0 1 2 3 4{
	sum wt_prov_ind_year if age>=20 & (inrange(income_imp,0,100000000) | wrk_busns==1) & gov_wkr!=1 & educ_sector!=1 & works==1 & rural==0 & sector_categ==`sector' & size!=., d 
	replace emp_bysector_size = wt_prov_ind_year/r(sum)*100 if sector_categ==`sector'

}


********************************************************************************
**
**		Display firm size distribution
**
********************************************************************************

tabstat empsize if age>=20 & (inrange(income_imp,0,100000000) | wrk_busns==1) & gov_wkr!=1 & educ_sector!=1 & works==1 & rural==0, s(sum) by(size) f(%12.6fc)

********************************************************************************
**
**		Export results for processing in code 2. Aggregate South Asia.do 
**
********************************************************************************

* 0. Total workers 
sum wt_prov_ind_year if  age>=20 & (inrange(income_imp,0,100000000) | wrk_busns==1) & gov_wkr!=1 & educ_sector!=1 & works==1 & rural==0
global nepal_pop = r(sum)

* 1. Total

preserve 

collapse (sum) empsize if  age>=20 & (inrange(income_imp,0,100000000) | wrk_busns==1) & gov_wkr!=1 & educ_sector!=1 & works==1 & rural==0, by(size)

drop if size==.
gen nepal_pop = $nepal_pop
mkmat empsize nepal_pop, matrix(Nepal)

restore


* 2. By sector

preserve 

bys sector_categ: egen pop = sum(wt_prov_ind_year)  if age>=20 & (inrange(income_imp,0,100000000) | wrk_busns==1) & gov_wkr!=1 & educ_sector!=1 & works==1 & rural==0


collapse (sum) emp_bysector_size (mean) pop if age>=20 & (inrange(income_imp,0,100000000) | wrk_busns==1) & gov_wkr!=1 & educ_sector!=1 & works==1 & rural==0, by(size sector_categ)

drop if size==.

reshape wide emp_bysector_size pop, i(size) j(sector_categ)
rename (emp_bysector_size*) (emp_others emp_industry  emp_wholret emp_othservices emp_agri) 
rename (pop*) (pop_others pop_industry pop_wholret pop_othservices pop_agri)
gen pop = $nepal_pop

gen country = "Nepal"

save "${results}/Temporary files/nepal_temp.dta", replace


restore

