********************************************************************************
**
**							1. Pakistan
**
********************************************************************************
**
**		This dofile processes the Pakistan Labour Force Survey to produce
**		the results that are used in 2. Aggregate South Asia.do for
**		Figures 1, 2, and A2.
**		Author: Nicolas Urdaneta 
**
********************************************************************************

cap log close
log using "${results}/Logs/Log 1 Pakistan `c(current_date)'.txt", replace text

use "${rawdata}/LFS 2018-19.dta", clear 

********************************************************************************
**
**		Check that some variables produce the correct aggregate statistics 
**
********************************************************************************

// Check some stats: 
tab S05C08 [aw=Weight] // Employment status 
tab S05C13 S05C08 [aw=Weight] ,m
sum S05C13 [aw=Weight],d

tab S05C13 S05C08 [aw=Weight] if S04C06>=20,m

********************************************************************************
**
**		Create variables for analysis
**
********************************************************************************

// Basic vars
gen age = S04C06
rename RespSex sex
gen agegroups = (age<15)*1 + (inrange(age,15,25))*2 + (inrange(age,26,45))*3 + (inrange(age,46,65))*4 + (inrange(age,65,1000))*5
gen educgroups = (S04C09<=5)*1+(inrange(S04C09,6,7))*2+(inrange(S04C09,8,15))*3
gen hrsworkgroups = 1*(inrange(S05C171,1,19))+2*(inrange(S05C171,20,39))+3*(inrange(S05C171,40,1000))

gen employed = (S05C01==1 | S05C18==1)

// Variables from processing code - see coding scheme 
tostring PrCode, replace 
gen province = substr(PrCode,1,1)
gen stratum = substr(PrCode,2,2)
gen ruralcode = substr(PrCode,4,1) 
gen rural = (ruralcode=="1")
tab rural [iw=Weight] // Checking that it is correct: should be 74M in urban, 128M in rural

// Note govt workers are not asked the firm size question so part of they will
// be dropped at that moment too
gen gov_wkr = inrange(S05C10,8400,8499)
gen educ_sector = inrange(S05C10,8500,8599) 
gen sector_categ = 1*(inrange(S05C10,0500,3999))+2*(inrange(S05C10,4500,4899) | inrange(S05C10,55000,56999))+3*(inrange(S05C10,5800,8299) | inrange(S05C10,9000,9999)) + 4*(inrange(S05C10,0,0499))
cap label drop categs
label define categs 1 "Industry" 2 "Services" 3 "Other services" 0 "Other sectors" 4 "Agriculture"
label values sector_categ categs
gen agro=(sector_categ==4)

// Create firm size variables
// We construct two versions: our most used with 11-50, 50-100, 100+ and one 
// fully comparable to India and Nepal with 11-19 and 20+
gen selfemployed = (inrange(S05C08,6,8))
gen size = 1 if selfemployed==1
replace size = 2 if inrange(S05C13,1,4) & selfemployed!=1
replace size = 3 if inrange(S05C13,5,10) & selfemployed!=1
replace size = 4 if inrange(S05C13,11,49) & selfemployed!=1
replace size = 5 if inrange(S05C13,50,100) & selfemployed!=1
replace size = 6 if inrange(S05C13,101,1000000) & selfemployed!=1
replace size = 2 if inrange(S05C13,1,4) & selfemployed!=1
replace size = 3 if inrange(S05C13,5,10) & selfemployed!=1
replace size = 4 if inrange(S05C13,11,49) & selfemployed!=1
replace size = 5 if inrange(S05C13,50,100) & selfemployed!=1
replace size = 6 if inrange(S05C13,101,1000000) & selfemployed!=1

gen size2 = 1 if selfemployed==1
replace size2 = 2 if inrange(S05C13,1,4) & selfemployed!=1
replace size2 = 3 if inrange(S05C13,5,10) & selfemployed!=1
replace size2 = 4 if inrange(S05C13,11,19) & selfemployed!=1
replace size2 = 5 if inrange(S05C13,20,10000000) & selfemployed!=1
replace size2 = 2 if inrange(S05C13,1,4) & selfemployed!=1
replace size2 = 3 if inrange(S05C13,5,10) & selfemployed!=1
replace size2 = 4 if inrange(S05C13,11,19) & selfemployed!=1
replace size2 = 5 if inrange(S05C13,20,10000000) & selfemployed!=1

cap label drop sizes
label define sizes 1 "Self-employed" 2 "1-4 workers" 3 "5-9 workers" 4 "10-19 workers" 5 "20+ workers"
label define sizesdet 1 "Self-employed" 2 "1-4 workers" 3 "5-9 workers" 4 "10-49 workers" 5 "50-100 workers" 6 "100+ workers"
label values size sizedet
label values size2 sizes

gen status = 1*(inrange(S05C08,1,4))+2*(inrange(S05C08,5,5))+3*(inrange(S05C08,6,8))+4*(inrange(S05C08,9,10))+5*(inrange(S05C08,11,13))+6*(inrange(S05C08,14,14))
gen paid_worker= (status==1) // Only kind of workers that report income in this survye: paid employees.

// Income variable (only for employees, so in this case we will not drop 
// self-employed without income)
replace S07C031=S07C031*4.333
replace S07C032=S07C032*4.333
replace S07C051=S07C051/12
replace S07C052=S07C052/12

egen incomept1 = rowtotal(S07C031 S07C032 S07C051 S07C052)
egen incomept2 = rowtotal(S07C041 S07C042)
egen income0 = rowmax(incomept1 incomept2)

*	____________________________________________________________________________
*
*			Impute income of those that report negative, zero or no income
*					but say they have a work with income
*	____________________________________________________________________________
 
gen income_censor = income0
replace income_censor = . if income0 <= 0

quantiles income_censor [iw=Weight], gencatvar(pctiles) n(100) stable
replace income_censor = . if inlist(pctiles,1,100)

global covs sex educgroups agegroups status hrsworkgroups agro

foreach var of global covs{
	replace income_censor = . if `var' == .
}

* ybar con factor de expansion
bys $covs: egen ing_mean_wt=wtmean(income_censor) if paid_worker==1 & income_censor>0 & income_censor!=., weight(Weight)
bys $covs: egen ing_i_mean_wt=min(ing_mean_wt) if paid_worker==1 

gen income_imp = income0
replace income_imp = ing_i_mean_wt if paid_worker == 1 & (income0==. | income0 <= 0) 
// We only impute 2 observations.
drop income_censor pctiles

// Create variables that will add to shares when collapsed
// Both in total and by sector
sum Weight  if age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & size2!=. & rural==0,d
gen empsize2 = Weight/r(sum)*100

gen emp_bysector_size=.
foreach sector in  0 1 2 3 4{
	sum Weight if age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0 & sector_categ==`sector' & size2!=., d 
	replace emp_bysector_size = Weight/r(sum)*100 if sector_categ==`sector'

}

********************************************************************************
**
**		Display firm size distribution with both of the distribution categories 
**
********************************************************************************

tabstat empsize2  if age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0, by(size2) s(sum) format(%12.6fc)
tabstat empsize2  if age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0, by(size) s(sum) format(%12.6fc)

********************************************************************************
**
**		Export results for processing in code 2. Aggregate South Asia.do 
**
********************************************************************************

* 0. Total workers 
sum Weight if  age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0 
global pakistan_pop = r(sum)

* 1. Total

preserve 

collapse (sum) empsize2 if  age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0, by(size2)

drop if size2==.
gen pakistan_pop = $pakistan_pop
mkmat empsize2 pakistan_pop, matrix(Pakistan)

restore

// Version of 11-50, 50-100 and 100+. This is used in Figure 2

preserve 

collapse (sum) empsize if  age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0, by(size)

drop if size==.
gen pakistan_pop = $pakistan_pop
mkmat empsize pakistan_pop, matrix(Pakistan_det)
mat l Pakistan_det
restore

* 2. By sector

preserve 

bys sector_categ: egen pop = sum(Weight) if age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0


collapse (sum) emp_bysector_size (mean) pop if age>=20 & (income_imp>0 | size==1) & gov_wkr!=1 & educ_sector!=1 & employed==1 & rural==0, by(size2 sector_categ)

drop if size2==.

reshape wide emp_bysector_size pop, i(size2) j(sector_categ)
rename (emp_bysector_size*) (emp_others emp_industry  emp_wholret emp_othservices emp_agri)
rename (pop*) (pop_others pop_industry pop_wholret pop_othservices pop_agri)

gen pop = $pakistan_pop
gen country = "Pakistan"
rename size2 size

save "${results}/Temporary files/pakistan_temp.dta", replace


restore

