********************************************************************************
**
**								United States
**
********************************************************************************
**
**		This dofile creates the information for the US.
**		It uses the CPS 2018-19 dataset downloaded from IPUMS.
**		Authors: Andrés Felipe Soto and Nicolas Urdaneta 
**
********************************************************************************

//set seed 83195
//set sortseed 83195
use "${rawdata}/cps_18.dta", clear

cap log close
log using "${results}/Logs/Log 1 USA `c(current_date)'.txt", replace text

*	____________________________________________________________________________
*
*							Create relevant variables
*	____________________________________________________________________________

keep if year==2018
sort serial cpsid pernum // To guarantee reproducibility 

// Person characteristics
gen agegroups = (age<15)*1 + (inrange(age,15,25))*2 + (inrange(age,26,45))*3 + (inrange(age,46,65))*4 + (inrange(age,65,1000))*5
gen hrsworkgroups = 1*(inrange(uhrsworkly,1,19))+2*(inrange(uhrsworkly,20,39))+3*(inrange(uhrsworkly,40,1000))
gen educgroups = (educ<=71)*1 + (inrange(educ,73,92))*2  + 3*(inrange(educ,111,125))

// Employed 
gen employee = (empstat==10 | empstat==12) if empstat!=0 // Empstat is a variable for current employment, not in the ASEC module. We won't use it.
gen paid_worker = (inrange(classwly,13,28))

// Self Employed
gen self_emp = (classwly==13)

// Firm sizes
gen firm1_9 = (firmsize==1 & self_emp!=1)
gen firm10plus = (firmsize>=2 & firmsize<=9 & self_emp!=1)
gen firm10_99 = (firmsize>=2 & firmsize<=6 & self_emp!=1)
gen firm100plus = (firmsize>=7 & firmsize<=9 & self_emp!=1)
gen firm10_49 = (firmsize==4 & self_emp!=1)
gen firm50_99 = (firmsize==6 & self_emp!=1)
gen firm50plus = (firmsize>=6 & firmsize<=9 & self_emp!=1)

// Additional firm sizes (only for 2018)
gen firm1to9 = (firmsize==1 & self_emp!=1 & year==2018)
gen firm10to49 = (firmsize==4 & self_emp!=1 & year==2018)
gen firm50to99 = (firmsize==6 & self_emp!=1 & year==2018)
gen firm100to499 = (firmsize==7 & self_emp!=1 & year==2018)
gen firm500to999 = (firmsize==8 & self_emp!=1 & year==2018)
gen firm1000plus = (firmsize==9 & self_emp!=1 & year==2018)


// Firm sizes split by salaried workers and owners
// Self employed - incorporated are considered owners
gen employee_micro = (firmsize==1 & self_emp!=1) & classwly==22  //1-9 employees
gen employee_nonmicro = (firmsize>=2 & firmsize<=9 & self_emp!=1) & classwly==22  // 10+ employees
gen owner_micro = (firmsize==1 & self_emp!=1) & classwly==14 //1-9 owners
gen owner_nonmicro = (firmsize>=2 & firmsize<=9 & self_emp!=1)  & classwly==14  // 10+ owners


// Government workers
gen gov_wkr=1 if inrange(classwly,25,28)
replace gov_wkr = 1 if inrange(indly,9370,9590)
replace gov_wkr=0 if gov_wkr==.

// Education sector
gen educ_sec=1 if inrange(indly,7860,7890)
replace educ_sec=0 if educ_sec==.

// Categories
gen categ = 1 if self_emp==1
replace categ=2 if employee_micro==1
replace categ=3 if employee_nonmicro==1
replace categ=4 if owner_micro==1
replace categ=5 if owner_nonmicro==1
replace categ=6 if firmsize==0 & categ==.
replace categ=7 if categ==.

label define categs 1 "Self employed unincorporated" 2 "Micro salaried" 3 "Nonmicro salaried" 4 "Micro owner" 5 "Nonmicro owner" 6 "Not employed" 7 "Non salaried workers"
label values categ categs
// Size 7 corresponds to government workers, 6 to not employed

tab categ [iw=asecwt],m

// Personal earnings - monthly
egen persincome=rowtotal(incwage incbus incfarm incwkcom)
gen persincome_monthly = persincome / wkswork1 * (52/12)

// Adjust household workers firm size
replace categ=2 if occly==4230 & firmsize==0

// Economic sectors (using the indly variable and following tge 2012 census industry classification to match the proposed arrangement of sectors)
gen agriculture = (indly>=170 & indly<=290)

gen industry = (indly>=1070 & indly<=3990) /*Manufacturing*/
replace industry = 1 if (indly>=370 & indly<=490) /*Mining, quarrying, and oil and gas extraction*/
replace industry = 1 if (indly>=570 & indly<=690) /*Utilities*/

gen wholeret_hosp = (indly>=4070 & indly<=5790) /*Wholesale and retail trade*/
replace wholeret_hosp = 1 if (indly>=8660 & indly<=8690) /*Accommodation and food services*/
replace wholeret_hosp = 1 if (indly>=8770 & indly<=8890) /*Repair and maintenance*/

gen other_services = (indly>=6870 & indly<=7190) /*Financial Activities*/ 
replace other_services = 1 if (indly>=7270 & indly<=7790) /*Professional and business services*/
replace other_services = 1 if (indly>=6470 & indly<=6780) /*Information*/ 
replace other_services = 1 if (indly>=8560 & indly<=8590) /*Arts, entertainment, and recreation*/ 
replace other_services = 1 if (indly>=8970 & indly<=9290) /*Other services excluding Repair and maintenance codes*/ 

*Create categorical with economic sectors
gen economic_sector = 1 if agriculture == 1
replace economic_sector = 2 if industry == 1
replace economic_sector = 3 if wholeret_hosp == 1
replace economic_sector = 4 if other_services == 1
label define economic_sector 1"Agriculture" 2"Industry" 3"Wholesale, retail, " 4"Other services"
label values economic_sector economic_sector
gen agro = (economic_sector==1)

*	____________________________________________________________________________
*
*			Impute income of those that report negative, zero or no income
*					but say they have a work with income
*	____________________________________________________________________________
 
gen persincome_censor = persincome_monthly
replace persincome_censor = . if persincome_monthly <= 0

quantiles persincome_censor [iw=asecwt], gencatvar(pctiles) n(100) stable
replace persincome_censor = . if inlist(pctiles,1,100)

global covs sex educgroups agegroups classwly hrsworkgroups agro

foreach var of global covs{
	replace persincome_censor = . if `var' == .
}

* ybar con factor de expansion
bys $covs: egen ing_mean_wt=wtmean(persincome_censor) if paid_worker==1 & persincome_censor>0 & persincome_censor!=., weight(asecwt)
bys $covs: egen ing_i_mean_wt=min(ing_mean_wt) if paid_worker==1 

gen persincome_imp = persincome_monthly
replace persincome_imp = ing_i_mean_wt if paid_worker == 1 & (persincome_monthly==. | persincome_monthly <= 0) 
// Changed 337 observations, 3 kept missing
drop persincome_censor pctiles

*	____________________________________________________________________________
*
*						Restrict to our relevant sample
*	____________________________________________________________________________

keep if age >= 20 & age != .
*keep if empstat==10 | empstat==12
keep if gov_wkr!=1
keep if educ_sec!=1
keep if categ!=6
keep if persincome_imp>0 & persincome_imp!=.
*keep if employee==1
drop if classwly==29

*	____________________________________________________________________________
*
*					Figure 1 : Distribution of firm size
*	____________________________________________________________________________

/// Panel A ////

preserve 

	keep if year==2018
	collapse (mean) self_emp firm1_9 firm10plus [aw=asecwt]
	foreach var in self_emp firm1_9 firm10plus{
		replace `var'=`var'*100
	}
	list
	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Fig1_US A") firstrow(variables)

restore

/// Panel B ////

preserve 

	keep if year==2018
	collapse (mean) self_emp firm1_9 firm10_49 firm50plus [aw=asecwt]
	// We split the 1-9 category using BDS data 
	// See BDS excel file for the fraction calculations
	gen firm1_4 = firm1_9*0.5004774
	gen firm5_9 = firm1_9*0.4995226
	drop firm1_9 
	order self_emp firm1_4 firm5_9 firm10_49 firm50plus
	foreach var in self_emp firm1_4 firm5_9 firm10_49 firm50plus{
		replace `var'=`var'*100
	}
	list
	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Fig1_US B") firstrow(variables)

restore

/// Panel C ////

preserve 

	keep if year==2018
	collapse (mean) self_emp firm1_9 firm10_49 firm50_99 firm100plus [aw=asecwt]
	// We split the 1-9 category using BDS data 
	// See BDS excel file for the fraction calculations
	gen firm1_4 = firm1_9*0.5004774
	gen firm5_9 = firm1_9*0.4995226
	drop firm1_9 
	order self_emp firm1_4 firm5_9 firm10_49 firm50_99 firm100plus
	foreach var in self_emp firm1_4 firm5_9 firm10_49 firm50_99 firm100plus{
		replace `var'=`var'*100
	}
	list
	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Fig1_US C") firstrow(variables)

restore

*	____________________________________________________________________________
*
*				Figure A2 and A3 : Distribution of firm size by sector
*	____________________________________________________________________________


// Panel A //
preserve
	keep if year==2018
	qui sum asecwt
	local totpop = r(sum)
	keep if economic_sector!=.
	gen pop=1
	collapse (mean) self_emp firm1_9 firm10plus (sum) pop [pw=asecwt], by(economic_sector)
	foreach var in self_emp firm1_9 firm10plus{
		replace `var'= `var'*100
	}
	gen fracpop = pop/`totpop'*100
	list
	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Fig1_US A by sectors") firstrow(variables)
restore

// Panel B //

preserve
	keep if year==2018
	qui sum asecwt
	local totpop = r(sum)
	keep if economic_sector!=.
	gen pop=1
	collapse (mean) self_emp firm1_9 firm10_49 firm50plus (sum) pop [pw=asecwt], by(economic_sector)
	// We split the 1-9 category using BDS data 
	// See BDS excel file for the fraction calculations 
	* Agriculture
	gen firm1_4 = firm1_9*0.53783406 if economic_sector==1
	gen firm5_9 = firm1_9*(1-0.53783406) if economic_sector==1
	* Industry 
	replace firm1_4 = firm1_9*0.41560133 if economic_sector==2
	replace firm5_9 = firm1_9*(1-0.41560133) if economic_sector==2
	* Wholesale, retail, accomodation services
	replace firm1_4 = firm1_9*0.45161633 if economic_sector==3
	replace firm5_9 = firm1_9*(1-0.45161633) if economic_sector==3
	* Other services 
	replace firm1_4 = firm1_9*0.52677517 if economic_sector==4
	replace firm5_9 = firm1_9*(1-0.52677517) if economic_sector==4
	order self_emp firm1_4 firm5_9 firm10_49 firm50plus
	foreach var in self_emp firm1_4 firm5_9 firm10_49 firm50plus{
		replace `var'= `var'*100
	}
	gen fracpop = pop/`totpop'*100

	drop firm1_9 
	list
	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Fig1_US B by sectors") firstrow(variables)
restore

// Panel C //

preserve
	keep if year==2018
	sum asecwt
	local totpop = r(sum)
	keep if economic_sector!=.
	gen pop=1
	collapse (mean) self_emp firm1_9 firm10_49 firm50_99 firm100plus (sum) pop [pw=asecwt], by(economic_sector)
	// We split the 1-9 category using BDS data 
	// See BDS excel file for the fraction calculations 
	* Agriculture
	gen firm1_4 = firm1_9*0.53783406 if economic_sector==1
	gen firm5_9 = firm1_9*(1-0.53783406) if economic_sector==1
	* Industry 
	replace firm1_4 = firm1_9*0.41560133 if economic_sector==2
	replace firm5_9 = firm1_9*(1-0.41560133) if economic_sector==2
	* Wholesale, retail, accomodation services
	replace firm1_4 = firm1_9*0.45161633 if economic_sector==3
	replace firm5_9 = firm1_9*(1-0.45161633) if economic_sector==3
	* Other services 
	replace firm1_4 = firm1_9*0.52677517 if economic_sector==4
	replace firm5_9 = firm1_9*(1-0.52677517) if economic_sector==4
	order self_emp firm1_4 firm5_9 firm10_49 firm50_99 firm100plus
	foreach var in self_emp firm1_4 firm5_9 firm10_49 firm50_99 firm100plus{
		replace `var'= `var'*100
	}
	gen fracpop = pop/`totpop'*100
	drop firm1_9 
	list
	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Fig1_US C by sectors") firstrow(variables)
restore

*	____________________________________________________________________________
*
*				 Figure 3: Distribution of firm size by income deciles
*	____________________________________________________________________________


//set sortseed 203232
//set sortseed 83195 // 262514
preserve 
	//set sortseed 423057
	//sort educgroups agegroups classwly sex agro hrsworkgroups
	*bys year: quantiles persincome_imp [iw=asecwt], gencatvar(decile) n(10)
	cap drop decile
	StableQuantiles persincome_imp [aw=asecwt] , bins(10) seed(262514) idvars( serial cpsid pernum ) genvar(decile)

	keep if year==2018
	collapse (mean) self_emp employee_micro owner_micro employee_nonmicro owner_nonmicro [aw=asecwt], by(decile)
	local dif = 0
	foreach var in self_emp employee_micro owner_micro employee_nonmicro owner_nonmicro{
		replace `var'= round(`var'*100)
	}
	list
	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Fig3_US") firstrow(variables) 

restore


*	____________________________________________________________________________
*
*					Table 2: Decomposition of personal earnings
*	____________________________________________________________________________
*4004
//set sortseed 423057 106671 203232 423057
//set sortseed 125925
preserve
	keep if year==2018
	keep if persincome_monthly>0 & persincome_monthly!=.
	
	egen p2_5_inctot=wpctile(persincome_monthly), p(2.5) weights(asecwt)
	egen p5_inctot=wpctile(persincome_monthly), p(5) weights(asecwt)

	gen sd_p5 = .
	sum persincome_monthly [aw=asecwt] if persincome_monthly<p5_inctot
	replace sd_p5=r(sd)


	gen cut = p2_5_inctot - sd_p5
	gen persincome_tr = persincome_monthly
	replace persincome_tr = cut if persincome_monthly<cut & cut!=.
	sum cut
	drop persincome_imp
	rename persincome_tr persincome_imp

	*bys year: quantiles persincome_imp [iw=asecwt], gencatvar(pctiles) n(10) 
	cap drop pctiles
	StableQuantiles persincome_imp [aw=asecwt] , bins(10) seed(262514) idvars( serial cpsid pernum ) genvar(pctiles)
	drop if pctiles == .

	// Income relative to median income
	egen median_inctot=wpctile(persincome_imp), by(year) p(50) weights(asecwt)

	// Compute share of population of each group and average distance in income for 
	// each group
	gen population=1

	gen relative_income=max(persincome_imp/median_inctot,median_inctot/persincome_imp)

	collapse (mean) relative_income median_inctot (sum) population [pw=asecwt],by(categ pctiles year)

	// Non micro owners have a tiny share in the first decile so we will exclude
	// them from the decomposition. They are about 0.1% of the population in 
	// the first decile
	foreach var in relative_income median_inctot population{
		replace `var'= . if pctiles==1 & categ==5
	}

	bys pctiles year: egen pop_pctile = total(population)

	gen population_share=population/pop_pctile 

	gen category_term=relative_income*population_share

	keep year categ pctiles category_term* relative_income* population_share*

	reshape wide category_term relative_income population_share , i(categ year) j(pctiles)

	order categ year population_share* relative_income* category_term*
	sort year categ

	list categ population_share1 relative_income1 category_term1 population_share10 relative_income10 category_term10

	
	sum relative_income1 if categ==1
	local m1 = r(mean)
	qui sum relative_income1 if categ==2
	local m2 = r(mean)
	qui sum relative_income1 if categ==3
	local m3 = r(mean)
	qui sum relative_income1 if categ==4
	local m4 = r(mean)
	sum relative_income10 if categ==1
	local b1 = r(mean)
	qui sum relative_income10 if categ==2
	local b2 = r(mean)
	qui sum relative_income10 if categ==3
	local b3 = r(mean)
	qui sum relative_income10 if categ==4
	local b4 = r(mean)

	if abs(`m1'-7.11)<0.005 & abs(`m2'-6.31)<0.005 & abs(`m3'-5.94)<0.005 & abs(`m4'-6.61)<0.005 & abs(`b1'-7.28)<0.005 & abs(`b2'-5.69)<0.005 & abs(`b3'-5.24)<0.005 & abs(`b4'-6.02)<0.005{
		dis as error "Seed `seed' is correct"
		exit 111
	}
	
	
	qui sum relative_income1
	dis "Within D1: " r(mean)
	qui sum category_term1
	dis "Total D1: " r(sum)
	qui sum relative_income10
	dis "Within D1: " r(mean)
	qui sum category_term10
	dis "Total D1: " r(sum)

	export excel categ population_share1 relative_income1 category_term1 population_share10 relative_income10 category_term10 using "${results}/Results US.xlsx", sheetreplace sheet("Table2_US") firstrow(variables) 

restore


*	____________________________________________________________________________
*
*				Auxiliary dataset: Employment share by income decile 
*	____________________________________________________________________________

preserve 

	keep if year==2018

	StableQuantiles persincome_imp [aw=asecwt] , bins(10) seed(262514) idvars( serial cpsid pernum ) genvar(decile)
	*quantiles persincome_imp [iw=asecwt], gencatvar(decile) n(10)

	collapse (mean) firmselfemployed = self_emp firm1to9 firm10to49 firm50to99 firm100to499 firm500to999 firm1000plus [aw=asecwt], by(decile)
	

	export excel using "${results}/Results US.xlsx", sheetreplace sheet("Database") firstrow(variables) 


restore
