/* FIGURE 1 - SIZE DISTRIBUTIONS
-------------------------------------------------------------------------------
- Panel A: size categories are 1-10, 11+
- Panel B: size categories are 1-4, 5-10, 11-50, 51 or more. 
- Panel C: size cateogires are 1-4,5-10, 11-50, 51-100, 101 or more.
-------------------------------------------------------------------------------
last change:
    14 Jun 2023
-------------------------------------------------------------------------------
Notes:
- Divides population into self-employed and business size categories
- Only individuals aged 20 or older, employed, with ing_lab > 0 & != . are kept.
- Excludes workers from the public and education sectors.
- For panels B and C instead of 50, the cutoff point for Argentina is 40, and for Costa Rica is 30.
- For panel C: for Brazil, Chile and Uruguay, 51-100 vs 100+ split is imputed using the average distribution across those two categories in the rest of LATAM.
-------------------------------------------------------------------------------
Author:
    Laura Tenjo (lauratenjo@worldbank.org)
-------------------------------------------------------------------------------
*/

cap log close
log using "${results}/Logs/Log 1.1 LATAM Figure 1 and Table A2 `c(current_date)'.txt", replace text

global paises Argentina_2019 Bolivia_2019 Brazil_2019 Chile_2017 Colombia_2019 CostaRica_2019 RepDom_2019 Mexico_2018 Paraguay_2019 Peru_2019 Uruguay_2019


* Create a temporary file to gradually add statistics
clear
tempfile temporal

* Create the variables used for merging as keys
gen pais = ""
gen year = ""
gen status_laboral = .
save `temporal', replace

* Run everything for each country
foreach file of global paises {
	
	dis in red " ############ `file' ########### "

	use "${processeddata}\latam_11_inisghts.dta" , clear
	keep if pais == "`file'"

	* Only keep population of interest
	keep if edad >= 20 & edad != .
	keep if ocupado == 1
	drop if ocupacion == .
	gen Q=1

	* Exclude workers from the public sector and the education sector
	drop if publico_educ == 1

	* Assign the smallest category to domestic workers without business size
	replace size_50_100 = 1 if empleada_domestica == 1 & size_50_100 == .
	replace size_50_100 = . if cuenta_propia == 1

	* Create divisions, which is the employment status, all categories are mutually exclusive
	gen status_laboral = size_50_100
	replace status_laboral = -1 if cuenta_propia == 1
	replace status_laboral = 99 if size_50_100 == . & cuenta_propia != 1 & ocupado == 1

	* Drop workers who are not self-employed and do not report business size
	drop if status_laboral == 99

	* Individual earnings Quintiles
	replace ing_lab = . if ing_lab <= 0
	quantiles ing_lab [iw=fac_exp_yr], gencatvar(quintiles) n(5) stable

	* Drop workers who do not report individual earnings
	drop if quintiles == .

	* Save the letters from the database name as the country and the numbers as the year
	cap drop pais
	gen pais = regexs(1) if regexm("`file'", "([A-Za-z]+)[_]")
	gen year = regexs(1) if regexm("`file'", "[_]([0-9]+)")

	* Collapse and merge with aggregate database
	collapse (sum) Q [iw=fac_exp_yr], by(pais year status_laboral)
	merge 1:1 pais year status using `temporal', nogen
	save `temporal', replace

}

use `temporal', replace
label var status "Category"
* Create variable of number of workers in the population of interest for weighted average
bys pais: egen total = sum(Q)

*******************************
* Panel A - 11+ distribution  *
*******************************

preserve

* Recode to get: self-employed; 1-10; 11+
recode status (2=1) (3=2) (4=2) (5=2)
label define size -1 "Self-employed" 1 "1-10" 2 "11 or more" 
label val status_laboral size
collapse (sum) Q (mean) total, by(status pais year)

* Employment weighted average for LAC 
gen share = Q/total*100
collapse (mean) share [w=total] , by(status)
format share %12.0fc
label var share "% of workers"

export excel using "$results\Results LATAM.xlsx", sheet("F1 - Size distribution",modify) firstrow(varlabels) cell(A1)

restore

*******************************
* Panel B - 51+ distribution  *
*******************************

preserve

* Recode to get: self-employed; 1-10; 11+
recode status (5=4)
label define size -1 "Self-employed" 1 "1-4" 2 "5-10" 3 "11-50" 4 "51 or more" 
label val status_laboral size
collapse (sum) Q (mean) total, by(status pais year)

* Employment weighted average for LAC 
gen share = Q/total*100
collapse (mean) share [w=total] , by(status)
format share %12.0fc
label var share "% of workers"

export excel using "$results\Results LATAM.xlsx", sheet("F1 - Size distribution",modify) firstrow(varlabels) cell(A6)

restore

*******************************
* Panel C - 101+ distribution *
*******************************

label define size -1 "Self employed" 1 "1-4" 2 "5-10" 3 "11-50" 4 "51-100" 5 "101 or more" , modify
label val status_laboral size
gen share = Q/total*100

* Data for each country (Table A.2) - using categories available for each country
preserve

keep pais status_laboral share 
order pais status_laboral share
sort pais status_laboral
format share %12.0fc

reshape wide share, i(status_laboral) j(pais) string
order status shareArgentina shareBolivia shareBrazil shareChile shareColombia shareCostaRica shareRepDom shareMexico shareParaguay sharePeru shareUruguay
rename (shareArgentina shareBolivia shareBrazil shareChile shareColombia shareCostaRica shareRepDom shareMexico shareParaguay sharePeru shareUruguay status) (Argentina Bolivia Brazil Chile Colombia CostaRica RepDom Mexico Paraguay Peru Uruguay Category)
export excel using "$results\Results LATAM.xlsx", sheet("T A2 - Size by country",modify) cell(A3) first(variables)

restore

** Note: Chile, Brazil, and Uruguay lack specific data regarding the distribution of workers in firms with 50 or more workers between those in firms with 50-100 workers and those in firms with 100+ workers. Consequently, to fill this data gap, workers in this category are categorized based on the average distribution observed in other countries.

* LATAM weighted average - 100+ distribution (with imputations for Brazil, Chile and Uruguay)
preserve

keep pais status_laboral share total
replace status = 0 if status == -1
reshape wide share, i(pais) j(status)

egen share_50 = rowtotal(share4 share5)
gen prop100 = share5/share_50
sum prop100 [w=total]

gen missing = 1 if share5 == .
replace share4 = share_50*(1-r(mean)) if missing == 1
replace share5 = share_50*(r(mean)) if missing == 1

drop share_50 prop100 missing
reshape long share, i(pais total) j(status)

collapse (mean) share [w=total] , by(status)
keep status share
format share %12.0fc
label var share "% of workers"

export excel using "$results\Results LATAM.xlsx", sheet("F1 - Size distribution",modify) firstrow(varlabels) cell(A13)

restore
