/* FIGURE 1 - SIZE DISTRIBUTIONS
-------------------------------------------------------------------------------
- Panel A: size categories are 1-10, 11+
- Panel B: size categories are 1-4, 5-10, 11-50, 51 or more. 
- Panel C: size cateogires are 1-4,5-10, 11-50, 51-100, 101 or more.
-------------------------------------------------------------------------------
last change:
    14 Jun 2023
-------------------------------------------------------------------------------
Notes:
- Divides population into self-employed and business size categories
- Only individuals aged 20 or older, employed, with ing_lab > 0 & != . are kept.
- Excludes workers from the public and education sectors.
- For panels B and C instead of 50, the cutoff point for Argentina is 40, and for Costa Rica is 30.
- For panel C: for Brazil, Chile and Uruguay, 51-100 vs 100+ split is imputed using the average distribution across those two categories in the rest of LATAM.
-------------------------------------------------------------------------------
Author:
    Laura Tenjo (lauratenjo@worldbank.org)
-------------------------------------------------------------------------------
*/

cap log close
log using "${results}/Logs/Log 1.1 LATAM Figure 3 and Table 2 `c(current_date)'.txt", replace text

global paises Argentina_2019 Bolivia_2019 Brazil_2019 Chile_2017 Colombia_2019 CostaRica_2019 RepDom_2019 Mexico_2018 Paraguay_2019 Peru_2019 Uruguay_2019

* Create a temporary file to gradually add statistics
clear
tempfile temporal
	
* creo las variables que usamos en el merge como llave
gen pais = ""
gen year = ""
gen deciles = .
gen status_laboral = .
save `temporal', replace 

* Empiezo a correr todo para cada una de las bases
foreach file of global paises {
dis in red " ############ `file' ########### "

	use "${processeddata}\latam_11_inisghts.dta" , clear
	keep if pais == "`file'"

	keep if ing_lab >0 
	keep if ing_lab != .
	keep if edad >= 20 & edad != .
	keep if ocupado == 1
	drop if ocupacion == .
	gen Q=1
	
	* Se eliminan trabajadores del sector publico y del sector educativo
	drop if publico_educ == 1
	
	* Se categoriza a los de la descomposicion
	gen size_emp_10 = size_50_100
	recode size_emp_10 (2=1) (3=2) (4=2) (5=2)

	* Se pone en la categoría más pequeña a empleada doméstica que no tenga tamaño
	replace size_emp_10 = 1 if empleada_domestica == 1 & size_emp_10 == .
	replace size_emp_10 = . if cuenta_propia == 1
	
	* Acá creamos uno de los cortes que es el estatus laboral, todas las categorias son excluyentes
	gen status_laboral = size_emp_10 if independiente == 0 
	replace status_laboral = size_emp_10+2 if independiente == 1 & cuenta_propia != 1
	replace status_lab = -1 if cuenta_propia == 1
	replace status_lab = 5 if size_emp_10 == . & cuenta_propia != 1 & ocupado == 1 
	replace status_lab = 6 if status_lab == .
	
	drop if inlist(status_lab,5,6)
	
	* Censuring 1SD
	egen p2_5_inctot=wpctile(ing_lab), p(2.5) weights(fac_exp_yr)
	egen p5_inctot=wpctile(ing_lab), p(5) weights(fac_exp_yr)
	egen sd_p5=sd(ing_lab) if ing_lab<p5_inctot

	gen cut = p2_5_inctot - sd_p5
	gen ing_lab_tr = ing_lab
	replace ing_lab_tr = cut if ing_lab<cut & cut!=.
	
	tabstat cut, s(mean)
	
	* Quintiles
	cap drop deciles
	replace ing_lab_tr = . if ing_lab <= 0
	*sort *
	set seed 1234
	*quantiles ing_lab_tr [iw=fac_exp_yr], gencatvar(deciles) n(10) stable
	StableQuantiles ing_lab_tr [iw=fac_exp_yr] , bins(10) seed(158207) idvars( ordering) /*sort(ordering)*/ genvar(deciles)

	drop if deciles == .
	sum ing_lab_tr [w=fac_exp_yr], d
	local median r(p50)
	gen median = `median'
	gen ratio = max(ing_lab_tr/median,median/ing_lab_tr)
	
	* Acá guardo las letras del nombre de la base y ese es el país y los números en el nombre y ese es el año
	cap drop pais
	cap drop year
	gen pais = regexs(1) if regexm("`file'", "([A-Za-z]+)[_]")
	gen year = regexs(1) if regexm("`file'", "[_]([0-9]+)")

	local list Q ratio
	
	* Doble local para el collapse mas tarde que saque estadisticas distintas para cada variable

	local Q sum
	local ratio mean

	
	* primer loop que va para cada una de las variables de arriba, hace collapse y mergea con la base
	foreach var of varlist `list' {
	dis in red "`sheet' ############ `file' ########### `var' Q"
	
	preserve
		collapse (``var'') `var' [iw=fac_exp_yr], by(pais year status_laboral deciles)
		
		merge 1:1 pais year deciles status using `temporal', nogen
		save `temporal', replace
		
	restore
		
	}
	
	* Corcehete loop por cada base
	}

/******************************************************************

Arreglos finales para ya exportar la base en orden, con nombres y sorteada
*******************************************************************/

use `temporal', replace


* Datos LAC todos los deciles
preserve

bys pais deciles: egen tot_decil = sum(Q) 
gen population_share = Q/tot_decil
bys pais: egen total_pais = sum(Q)

fillin status_labor pais deciles 
replace population_share = 0 if _fillin == 1
bys pais: egen total = min(total_pais) 
gen share_rel = population_share*ratio
collapse (mean) population_share ratio share_rel [w=total], by(status deciles)
keep status_laboral deciles population_share ratio share_rel

drop ratio share_rel
recode status (-1=0)
replace population_share = population_share*100
reshape wide population_share, i(deciles) j (status)
rename (population_share0 population_share1 population_share2 population_share3 population_share4) (self_employed employee1_10 employee_11more owner1_10 owner_11more)
order deciles self_employed employee1_10 owner1_10 employee_11more owner_11more

label var deciles "Income decile"
label var self_employed "Self-employed without employees"
label var employee1_10 "Employees 1-10"
label var owner1_10 "Business owners 1-10"
label var employee_11more "Employees 11+"
label var owner_11more "Business owners 11+"

list 
export excel using "$results\Results LATAM.xlsx", sheet("F3 - Distribution by decile",modify) firstrow(varlabels) cell (A1)

restore

keep if inlist(deciles,1,10)

* Promedio ponderado por trabajadores de LAC 
preserve

// Non micro owners have a tiny share in the first decile so we will exclude
// them from the decomposition. They are about 0.1% of the population in 
// the first decile
foreach var in Q ratio{
	replace `var'= . if decil==1 & status_laboral==4
}

bys pais deciles: egen tot_decil = sum(Q) 
gen population_share = Q/tot_decil
bys pais: egen total_pais = sum(Q)

fillin status_labor pais deciles 
replace population_share = 0 if _fillin == 1 & (decil!=1 | status_laboral!=4)

bys pais: egen total = min(total_pais) 
gen share_rel = population_share*ratio
collapse (mean) population_share ratio share_rel [w=total], by(status deciles)
reshape wide population_share ratio share_rel, i(status_laboral) j(deciles)

format ratio* share_rel* %12.2fc
format population_share* %12.3fc

label define status -1 "Self-employed without employees" 1 "Worker in less than 10 employee business" 2 "Worker in 11+ employee business" 3 "Owner of less than 10 employee business" 4 "Owner of 11+ employee business"
label val status status

label var status "Category"
label var population_share1 "Share D1"
label var ratio1 "P50/D1"
label var share_rel1 "Share * P50/D1"
label var population_share10 "Share D10"
label var ratio10 "D10/P50"
label var share_rel10 "Share * D10/P50"

list *1 *10
export excel using "$results\Results LATAM.xlsx", sheet("T2 - decomposition",modify) cell(A1)  firstrow(varlabels) 

restore

