/* FIGURE - SIZE DISTRIBUTIONS BY SECTOR
-------------------------------------------------------------------------------
- Panel A: size categories are 1-10, 11+
- Panel B: size categories are 1-4, 5-10, 11-50, 51 or more. 
- Panel C: size cateogires are 1-4,5-10, 11-50, 51-100, 101 or more.

Sectors: 1. Industry 2. Commerce including hotel and restaurants 3. Other services
4. Agriculture
-------------------------------------------------------------------------------
last change:
    16 Jun 2023
-------------------------------------------------------------------------------
Notes:
- Divides population into self-employed and business size categories for different sectors of activity.
- Only individuals aged 20 or older, employed, with ing_lab > 0 & != . are kept.
- Excludes workers from the public and education sectors.
- For panels B and C instead of 50, the cutoff point for Argentina is 40, and for Costa Rica is 30.
- For panel C: for Brazil, Chile and Uruguay, 51-100 vs 100+ split is imputed using the average distribution across those two categories in the rest of LATAM.
-------------------------------------------------------------------------------
Author:
    Laura Tenjo (lauratenjo@worldbank.org)
-------------------------------------------------------------------------------
*/

cap log close
log using "${results}/Logs/Log 1.1 LATAM Figure A2 and A3 `c(current_date)'.txt", replace text

cls 

global paises Argentina_2019 Bolivia_2019 Brazil_2019 Chile_2017 Colombia_2019 CostaRica_2019 RepDom_2019 Mexico_2018 Paraguay_2019 Peru_2019 Uruguay_2019
	
* Create a temporary file to gradually add statistics
clear
tempfile temporal

* Create the variables used for merging as keys
gen pais = ""
gen year = ""
gen status_laboral = .
gen sector = .
save `temporal', replace

* Run everything for each country
foreach file of global paises {
	
	dis in red " ############ `file' ########### "

	use "${processeddata}\latam_11_inisghts.dta" , clear
	keep if pais == "`file'"

	* Only keep population of interest
	keep if edad >= 20 & edad != .
	keep if ocupado == 1
	drop if ocupacion == .
	gen Q=1

	* Exclude workers from the public sector and the education sector
	drop if publico_educ == 1
	
	* Create sectors of interest
	drop if sector_rev4 == . // Only keep observations who report economic sector
	
	gen sector = . 
	replace sector = 1 if inlist(sector_rev4,2,3,4) 	 //industry
	replace sector = 2 if sector_rev4 == 6 				 //commerce and accomodation
	replace sector = 3 if inlist(sector_rev4,8,11,12,13) //other services
	replace sector = 4 if inlist(sector_rev4,1)			 //agriculture 
	replace sector = 0 if sector == . & sector_rev4 != . //other sectors
	drop if sector == .
	
	label define sector 1 "Industry" 2 "Wholesale, retail and hospitality" 3 "Other services" 4 "Agriculture" 0 "Other sectors"
	label val sector sector
	
	* Assign the smallest category to domestic workers without business size
	replace size_50_100 = 1 if empleada_domestica == 1 & size_50_100 == .
	replace size_50_100 = . if cuenta_propia == 1

	* Create divisions, which is the employment status, all categories are mutually exclusive
	gen status_laboral = size_50_100
	replace status_laboral = -1 if cuenta_propia == 1
	replace status_laboral = 99 if size_50_100 == . & cuenta_propia != 1 & ocupado == 1

	* Drop workers who are not self-employed and do not report business size
	drop if status_laboral == 99

	* Individual earnings Quintiles
	replace ing_lab = . if ing_lab <= 0
	quantiles ing_lab [iw=fac_exp_yr], gencatvar(quintiles) n(5) stable

	* Drop workers who do not report individual earnings
	drop if quintiles == .

	* Save the letters from the database name as the country and the numbers as the year
	cap drop pais
	gen pais = regexs(1) if regexm("`file'", "([A-Za-z]+)[_]")
	gen year = regexs(1) if regexm("`file'", "[_]([0-9]+)")

	* Collapse and merge with aggregate database
	collapse (sum) Q [iw=fac_exp_yr], by(pais year status_laboral sector)
	merge 1:1 pais year status sector using `temporal', nogen
	save `temporal', replace

}

use `temporal', replace

* Create variable of number of workers in the population of interest for weighted average
bys pais sector: egen total = sum(Q)

*******************************
* % of workers in each sector *
*******************************

preserve

expand 2, gen(new)
replace pais = "latam" if new == 0
replace year = "2019" if new == 0

collapse (sum) Q, by(pais year sector)
bys pais: egen total_w = sum(Q)
gen share = Q/total_w*100

keep pais year sector share
order pais year sector share
drop if sector == 0

keep if pais == "latam" // This is because we are only showing % for latam. Comment this line to get the shares for each country.

export excel using "$results/Results LATAM.xlsx", sheet("FA2-3 - Size distr by sector",modify) firstrow(variables) cell(A1)

restore 

*******************************
* Panel A - 11+ distribution  *
*******************************
drop if sector == 0 //only used before to calculate denominator of all workers who report sector

preserve

* Recode to get: self-employed; 1-10; 11+
recode status (2=1) (3=2) (4=2) (5=2)
label define size -1 "Self-employed" 1 "1-10" 2 "11 or more" 
label val status_laboral size
collapse (sum) Q (mean) total, by(pais year sector status)

* Employment weighted average for LATAM 
gen share = Q/total*100
collapse (mean) share [w=total] , by(sector status)
format share %12.0fc

reshape wide share, i(status) j(sector)
rename (share1 share2 share3 share4) (industry commerce_hotels other_services agriculture)

export excel using "$results/Results LATAM.xlsx", sheet("FA2-3 - Size distr by sector",modify) firstrow(variables) cell(G1)

restore

*******************************
* Panel B - 51+ distribution  *
*******************************

preserve

* Recode to get: self-employed; 1-10; 11+
recode status (5=4)
label define size -1 "Self-employed" 1 "1-4" 2 "5-10" 3 "11-50" 4 "51 or more" 
label val status_laboral size
collapse (sum) Q (mean) total, by(pais year sector status)

* Employment weighted average for LATAM 
gen share = Q/total*100
collapse (mean) share [w=total] , by(sector status)
format share %12.0fc

reshape wide share, i(status) j(sector)
rename (share1 share2 share3 share4) (industry commerce_hotels other_services agriculture)

export excel using "$results/Results LATAM.xlsx", sheet("FA2-3 - Size distr by sector",modify) firstrow(variables) cell(G6)

restore



